#
# Conditional build:
%bcond_without	python2		# CPython 2.x module
%bcond_without	python3		# CPython 3.x module
%bcond_without	tests		# unit tests
%bcond_with	tests_net	# unit tests using network

%define		module	cssutils
%define		encutils_ver 0.9.8
Summary:	A CSS Cascading Style Sheets library for Python 2
Summary(pl.UTF-8):	Biblioteka CSS (Cascading Style Sheets) dla Pythona 2
Name:		python-%{module}
Version:	1.0.2
Release:	9
Epoch:		1
License:	LGPL v3+
Group:		Libraries/Python
Source0:	https://files.pythonhosted.org/packages/source/c/cssutils/%{module}-%{version}.tar.gz
# Source0-md5:	dc66d96c2d78f1687f59ac412fe9d318
Patch0:		%{name}-tests.patch
Patch1:		%{name}-mock.patch
URL:		http://cthedot.de/cssutils/
%if %{with python2}
BuildRequires:	python-devel >= 1:2.5
%{?with_tests:BuildRequires:	python-mock}
BuildRequires:	python-setuptools
%endif
%if %{with python3}
BuildRequires:	python3-2to3 >= 1:3.2
BuildRequires:	python3-devel >= 1:3.2
BuildRequires:	python3-setuptools
%endif
BuildRequires:	rpm-pythonprov
BuildRequires:	rpmbuild(macros) >= 1.714
Requires:	python-modules >= 1:2.5
Provides:	python-encutils = %{encutils_ver}
Obsoletes:	python-encutils < %{encutils_ver}
BuildArch:	noarch
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
A Python package to parse and build CSS Cascading Style Sheets. Partly
implements the DOM Level 2 Stylesheets and DOM Level 2 CSS interfaces.

%description -l pl.UTF-8
Pakiet Pythona do analizy i tworzenia CSS (Cascading Style Sheets).
Częściowo implementuje interfejsy DOM Level 2 Stylesheets oraz DOM
Level 2 CSS.

%package -n python3-%{module}
Summary:	A CSS Cascading Style Sheets library for Python 3
Summary(pl.UTF-8):	Biblioteka CSS (Cascading Style Sheets) dla Pythona 3
Group:		Libraries/Python
Requires:	python3-modules >= 1:3.2

%description -n python3-%{module}
A Python package to parse and build CSS Cascading Style Sheets. Partly
implements the DOM Level 2 Stylesheets and DOM Level 2 CSS interfaces.

%description -n python3-%{module} -l pl.UTF-8
Pakiet Pythona do analizy i tworzenia CSS (Cascading Style Sheets).
Częściowo implementuje interfejsy DOM Level 2 Stylesheets oraz DOM
Level 2 CSS.

%prep
%setup -q -n %{module}-%{version}
%patch0 -p1
%patch1 -p1

eval $(PYTHONPATH=src python -c "from encutils import VERSION;print 'VERSION=%%s' %% VERSION")
if [ $VERSION != %{encutils_ver} ]; then
	echo "Please set encutils_ver to $VERSION"
	exit 1
fi

%if %{without tests_net}
%{__sed} -i -e 's/def test_parseUrl/def skip_parseUrl/' src/cssutils/tests/test_parse.py
%{__sed} -i -e 's/def test_handlers/def skip_handlers/' src/cssutils/tests/test_errorhandler.py
%endif

%build
%if %{with python2}
%py_build

%if %{with tests}
%{__python} -m unittest discover -t build-2/lib -s build-2/lib/cssutils/tests
%endif
%endif

%if %{with python3}
%py3_build

%if %{with tests}
%{__python3} -m unittest discover -t build-3/lib -s build-3/lib/cssutils/tests
%endif
%endif

%install
rm -rf $RPM_BUILD_ROOT

%if %{with python3}
%py3_install

for f in csscapture csscombine cssparse ; do
	%{__mv} $RPM_BUILD_ROOT%{_bindir}/$f $RPM_BUILD_ROOT%{_bindir}/${f}-3
done

%{__rm} -r $RPM_BUILD_ROOT%{py3_sitescriptdir}/cssutils/tests
%endif

%if %{with python2}
%py_install

for f in csscapture csscombine cssparse ; do
	%{__mv} $RPM_BUILD_ROOT%{_bindir}/$f $RPM_BUILD_ROOT%{_bindir}/${f}-2
	ln -sf ${f}-2 $RPM_BUILD_ROOT%{_bindir}/$f
done

%py_postclean
%{__rm} -r $RPM_BUILD_ROOT%{py_sitescriptdir}/cssutils/tests
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%if %{with python2}
%files
%defattr(644,root,root,755)
%doc README.txt
%attr(755,root,root) %{_bindir}/csscapture
%attr(755,root,root) %{_bindir}/csscombine
%attr(755,root,root) %{_bindir}/cssparse
%attr(755,root,root) %{_bindir}/csscapture-2
%attr(755,root,root) %{_bindir}/csscombine-2
%attr(755,root,root) %{_bindir}/cssparse-2
%{py_sitescriptdir}/cssutils
%{py_sitescriptdir}/encutils
%{py_sitescriptdir}/cssutils-%{version}-py*.egg-info
%endif

%if %{with python3}
%files -n python3-%{module}
%defattr(644,root,root,755)
%attr(755,root,root) %{_bindir}/csscapture-3
%attr(755,root,root) %{_bindir}/csscombine-3
%attr(755,root,root) %{_bindir}/cssparse-3
%{py3_sitescriptdir}/cssutils
%{py3_sitescriptdir}/encutils
%{py3_sitescriptdir}/cssutils-%{version}-py*.egg-info
%endif
%changelog
* Thu Mar 31 2022 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/python-cssutils.git;a=log;h=auto/th/python-cssutils-1.0.2-9

* Wed Mar 30 2022 Jan Rękorajski <baggins@pld-linux.org> 5f9a08a
- rebuild with tests and docs

* Sat Mar 26 2022 Jan Rękorajski <baggins@pld-linux.org> e72c597
- rebuild with python 3.10

* Fri Mar 25 2022 Jan Rękorajski <baggins@pld-linux.org> 5d19013
- rebuild with python 3.10

* Tue Mar 02 2021 Jan Palus <atler@pld-linux.org> fb9c2bb
- noarch; rel 6

* Sun Aug 30 2020 Jakub Bogusz <qboosh@pld-linux.org> 21a0a31
- enchanced tests patch

* Mon Oct 28 2019 Jan Rękorajski <baggins@pld-linux.org> bb93a71
- rebuild with python 3.8
- release 5 (by relup.sh)

* Tue Jul 03 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> bee3c32
- release 4 (by relup.sh)

* Sun Jul 01 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> dcff555
- python 3.7 rebuild
- release 3 (by relup.sh)

* Tue Jul 04 2017 Jakub Bogusz <qboosh@pld-linux.org> e1cf6bb
- disable network related tests by default; release 2

* Mon Jul 03 2017 Jakub Bogusz <qboosh@pld-linux.org> 94d7230
- Source0 URL fix

* Mon Jul 03 2017 Jakub Bogusz <qboosh@pld-linux.org> 9565b20
- updated to 1.0.2
- added tests patch (fixes tests with CPython 2.x)
- added mock patch (don't require external mock with python 3, unittest.mock is enough)
- added python3- package

* Sun Nov 29 2015 Jacek Konieczny <jajcus@jajcus.net> 985e837
- BR: rpmbuild(macros) >= 1.710

* Sat Nov 28 2015 Jacek Konieczny <jajcus@jajcus.net> d3137d0
- release 4 (by relup.sh)

* Sat Nov 28 2015 Jacek Konieczny <jajcus@jajcus.net> 7737135
- automatic change: use py_build/py_install macros

* Fri Mar 20 2015 Elan Ruusamäe <glen@delfi.ee> 5abb534
- x32 rebuild
- release 3 (by relup.sh)

* Thu Jun 21 2012 Jan Rękorajski <baggins@pld-linux.org> 4b3a8c5
- rel 2

* Wed Jun 13 2012 Jacek Konieczny <jajcus@pld-linux.org> 11143dd
- encutils_ver: 0.9.8

* Sun Jun 10 2012 Paweł Gołaszewski <blues@pld-linux.org> 0b6d5cd
- 0.9.9

* Mon Jan 10 2011 lisu <lisu@pld-linux.org> 2c1855b
- final stable version is 0.9.7, move 0.9.8 to DEVEL
- epoch 1

* Mon Jan 03 2011 lisu <lisu@pld-linux.org> 3feca1f
- 0.9.8a1
- rpm-build-macros >= 1.219 required (for py_postclean macro)

